Splash screen with waves animation shown before the main TUI.
Functions
- run_
splash - Run the splash screen: waves animation + title. Returns when duration elapsed or any key pressed.
Splash screen with waves animation shown before the main TUI.